@@ -6,6 +6,8 @@
 #include "externalipresolver.h"
 #include "rtt.h"
 
+#include <wx/regex.h>
+
 #define RECVBUFFERSIZE 4096
 #define MAXLINELEN 2000
 
@@ -92,6 +94,8 @@ protected:
 	// It's the last line in a multi-line response.
 	void ParseResponse();
 
+	void ParseFeat(wxString const& line);
+
 	virtual int SendNextCommand();
 	virtual int ParseSubcommandResult(int prevResult);
 
@@ -144,7 +148,7 @@ protected:
 
 	// Used by keepalive code so that we're not using keep alive
 	// till the end of time. Stop after a couple of minutes.
-	wxDateTime m_lastCommandCompletionTime;
+	CMonotonicClock m_lastCommandCompletionTime;
 
 	timer_id m_idleTimer{};
 
@@ -154,6 +158,8 @@ protected:
 
 	void OnExternalIPAddress();
 	void OnTimer(timer_id id);
+
+	wxRegEx m_pasvReplyRegex; // Have it as class member to avoid recompiling the regex on each transfer or listing
 };
 
 class CIOThread;
